safetybox v0.1.2
Modules summary ↑
| Mix.Tasks.Safetybox.Decrypt | This task will decrypt your password (or any text) using the provided SALT and SECRET This should be considered more secure than plan text passwords, but not much |
| Mix.Tasks.Safetybox.Encrypt | This task will encrypt your password (or any text) using the provided SALT and SECRET This should be considered more secure than plan text passwords, but not much |
| Safetybox | Safetybox a collection of security oriented functionsThis is oriented towards individuals that store passwordsdirectly in their code, or some other not-so-hard-to-find locationDependency
UsageAPI
|